@@ -30,10 +30,11 @@ class QuerySet:
         appendix = ""
         if len(result) > 20:
             appendix = " ..remainung elements truncated."
-        return "%s%s" % (str([item for item in result]), appendix)
+        return "%s%s" % (str([item for item in result[:20]]), appendix)
 
     def __len__(self):
-        return self.count()
+        result = self()
+        return len(result)
 
     def make_objects(self, instance, db_results) -> list:
         objects = []
@@ -54,13 +55,15 @@ class QuerySet:
 
         return objects
 
-    def _make_all_query(self):
-        if self.partials['all']:
+    def _make_query_base(self):
+        if self.partials['count'] == True:
+            self.query = self.adaptor.get_count_query(self.base)
+        else:
             self.query = self.adaptor.get_select_query(self.base)
 
     def _make_where_clause(self):
         if self.partials['filters'] or self.partials['excludes']:
-            self.query = self.adaptor.get_select_query(self.base) + ' WHERE '
+            self.query += ' WHERE '
 
     def _make_updates(self):
         if self.partials['updates']:
@@ -117,7 +120,7 @@ class QuerySet:
     def compile_query(self) -> tuple:
         self.query_args = []
 
-        self._make_all_query()
+        self._make_query_base()
         self._make_where_clause()
         self._make_updates()
         self._make_deletions()
@@ -135,6 +138,8 @@ class QuerySet:
 
     def __call__(self):
         result = self.execute_sql()
+        if self.partials['count']:
+            return result[0][0]
         return self.make_objects(self.base, result)
 
     def __iter__(self):
@@ -182,7 +187,7 @@ class QuerySet:
             count_qs = QuerySet(self.base)
             for item in filters:
                 count_qs = count_qs.filter(**item)
-            count = count_qs.count()
+            count = len(count_qs)
 
         for key, value in kwargs.items():
             self.partials['updates'].append({key: value})
@@ -200,7 +205,8 @@ class QuerySet:
             return result[0]
 
     def count(self):
-        return len(self())
+        self.partials['count'] = True
+        return self()
 
     def exists(self):
-        return self.count() > 0
+        return len(self) > 0
